require "test_helper"

class Api::V1::ActivitiesControllerTest < ActionDispatch::IntegrationTest
  setup do
    @activity = activities(:one)
    @user = users(:one)
  end
  
  #INDEX
  test "should access index" do
    get api_v1_activities_url,
    headers: { Authorization: JsonWebToken.encode(user_id: @activity.author_id) },
    as: :json
    assert_response :success
  end

  test "should not access index" do
    get api_v1_activities_url, as: :json
    assert_response :forbidden
  end

  #SHOW
  test "should access show" do
    get api_v1_activity_url(@activity),
    headers: { Authorization: JsonWebToken.encode(user_id: @activity.author_id) },
    as: :json
    assert_response :success
  end

  test "should not access show" do
    get api_v1_activity_url(@activity),
    as: :json
    assert_response :forbidden
  end

  #CREATE
  test "should create activity" do
    assert_difference("Activity.count") do
      post api_v1_activities_url,
      params: { activity: { name: @activity.name, client: @activity.client, description: @activity.description, author_id: @user }},
      headers: { Authorization: JsonWebToken.encode(user_id: @activity.author_id) },
      as: :json
    end
    assert_response :created
  end

  test "should forbid create activity" do
    assert_no_difference "Activity.count" do
      post api_v1_activities_url,
      params: { activity: { name: @activity.name, client: @activity.client, description: @activity.description, author_id: @user } },
      as: :json
    end
    assert_response :forbidden
  end

  #UPDATE
  test "should update activity" do
    patch api_v1_activity_url(@activity),
    params: { activity: { name: "Updated name" } },
    headers: { Authorization: JsonWebToken.encode(user_id: @activity.author_id) },
    as: :json
    assert_response :success
  end

  test "should forbid update activity - not logged in" do
    patch api_v1_activity_url(@activity),
    params: { activity: { name: "Updated name" } },
    as: :json
    assert_response :forbidden
  end

  test "should forbid update activity - not owner or admin" do
    patch api_v1_activity_url(@activity),
    params: { activity: { name: "Updated name" } },
    headers: { Authorization: JsonWebToken.encode(user_id: users(:two).id) },
    as: :json
    assert_response :forbidden
  end

  #DESTROY
  test "should destroy activity" do
    assert_difference "Activity.count", -1 do
    delete api_v1_activity_url(@activity),
    headers: { Authorization: JsonWebToken.encode(user_id: @activity.author_id) },
    as: :json
    end
    assert_response :no_content
  end

  test "should forbid destroy activity - not logged in" do
    assert_no_difference('Activity.count') do
      delete api_v1_activity_url(@activity), as: :json
    end
    assert_response :forbidden
  end

  test "should forbid destroy activity - not owner or admin" do
    assert_no_difference('Activity.count') do
    delete api_v1_activity_url(@activity),
    headers: { Authorization: JsonWebToken.encode(user_id: users(:two).id) },
    as: :json
    end
    assert_response :forbidden
  end
end